<?php

namespace Drupal\Tests\commerce_registration\Kernel\Plugin\Field\Formatter;

use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\Core\DependencyInjection\ServiceModifierInterface;
use Drupal\Tests\commerce_registration\Kernel\CurrentRouteMatch;
use Drupal\Tests\commerce_registration\Traits\ProductCreationTrait;
use Drupal\Tests\commerce_registration\Traits\ProductVariationCreationTrait;

/**
 * Tests the registration_form formatter.
 *
 * @coversDefaultClass \Drupal\commerce_registration\Plugin\Field\FieldFormatter\RegistrationFormFormatter
 *
 * @group commerce_registration
 */
class RegistrationFormFormatterTest extends FormatterTestBase implements ServiceModifierInterface {

  use ProductCreationTrait;
  use ProductVariationCreationTrait;

  /**
   * {@inheritdoc}
   */
  public function alter(ContainerBuilder $container) {
    // Set up an override that returns the route for
    // commerce_product_variation/1. The route is needed during form rendering.
    $service_definition = $container->getDefinition('current_route_match');
    $service_definition->setClass(CurrentRouteMatch::class);
  }

  /**
   * @covers ::render
   */
  public function testRegistrationFormFormatter() {
    $product = $this->createAndSaveProduct();
    $variation = $this->createAndSaveVariation($product);
    $build = $variation->get('event_registration')->view([
      'type' => 'registration_form',
      'label' => 'hidden',
    ]);
    $output = $this->renderPlain($build);
    $this->assertStringContainsString('<form class="registration-conference-register-form', $output);
  }

}
